::*************************************************************************::
::  CUBE        http://www.scalasca.org/                                   ::
::*************************************************************************::
::  Copyright (c) 2009-2022                                                ::
::  Forschungszentrum Juelich GmbH, Juelich Supercomputing Centre          ::
::                                                                         ::
::  Copyright (c) 2009-2021                                                ::
::  German Research School for Simulation Sciences GmbH,                   ::
::  Laboratory for Parallel Programming                                    ::
::                                                                         ::
::  Copyright (c) 2009-2014                                                ::
::  RWTH Aachen University, IT Center                                      ::
::                                                                         ::
::  Copyright (c) 2009-2014                                                ::
::  Gesellschaft fuer numerische Simulation mbH Braunschweig, Germany      ::
::                                                                         ::
::  Copyright (c) 2009-2014                                                ::
::  TU Dresden, Zentrum fuer Informationsdienste und Hochleistungsrechnen  ::
::                                                                         ::
::  Copyright (c) 2009-2014                                                ::
::  University of Oregon, Eugene, USA                                      ::
::                                                                         ::
::  Copyright (c) 2009-2014                                                ::
::  Technische Universitaet Muenchen, Germany                              ::
::                                                                         ::
::  This software may be modified and distributed under the terms of       ::
::  a BSD-style license.  See the COPYING file in the package base         ::
::  directory for details.                                                 ::
::*************************************************************************::


:: maintainer Pavel Saviankou <p.saviankou@fz-juelich.de>
set MINGW="C:\QtSDK\5.13.1\mingw73_64"
set QTDIR="C:\QtSDK\5.13.1\mingw73_64"
set NSIS="C:\Program Files (x86)\NSIS"
set srcdir=..\..\
set PWD=%~dp0
set PREFIX=%1
set TARGET=C:\Scalasca-Soft\Install\Cube2.0\%PREFIX%\install


mkdir %TARGET%\bin
mkdir %TARGET%\lib
mkdir %TARGET%\include\cubew
mkdir %TARGET%\include\cubelib
mkdir %TARGET%\include\cubegui
mkdir %TARGET%\share\icons
mkdir %TARGET%\share\doc\cubegui\examples
mkdir %TARGET%\share\doc\cubegui\guide
mkdir %TARGET%\share\doc\cubegui\plugins-guide

echo "Read version and SHA in VERSION and REVISION files"

cat ../../build-config/VERSION | grep "package.major"  | sed -e "s/package\.major=//g"> package.major
cat ../../build-config/VERSION | grep "package.minor"  | sed -e "s/package\.minor=//g"> package.minor
cat ../../build-config/VERSION | grep "package.bugfix" | sed -e "s/package\.bugfix=//g"> package.bugfix
cat ../../build-config/VERSION | grep "package.suffix" | sed -e "s/package\.suffix=//g"> package.suffix

set /p REVISION=<../../build-config/REVISION

echo "Read Cube version"
set /p PACKAGEMAJOR=<package.major

set /p PACKAGEMINOR=<package.minor

set /p PACKAGEBUGIX=<package.bugfix

set /p PACKAGESUFFIX=<package.suffix

del package.major
del package.minor
del package.bugfix
del package.suffix

echo "Backup"
cp ./include/cubegui-version.h ./cubegui-version.source
ls
echo "Fix version and SHA in version.h"
cat cubegui-version.source | sed -e "s/<REVISION SHA>/%REVISION%/g" | sed -e "s/<PACKAGE MAJOR>/%PACKAGEMAJOR%/g" |   sed -e "s/<PACKAGE MINOR>/%PACKAGEMINOR%/g" |   sed -e "s/<PACKAGE BUGFIX>/%PACKAGEBUGIX%/g" |   sed -e "s/<PACKAGE SUFFIX>/%PACKAGESUFFIX%/g"  > ./include/cubegui-version.h

for %%f in (
GUI-qt-core
GUI-qt
GUI-plugin-advanced-colormap
GUI-plugin-advisor
GUI-plugin-graphwidgetcommon
GUI-plugin-barplot
GUI-plugin-diff
GUI-plugin-heatmap
GUI-plugin-launch
GUI-plugin-mean
GUI-plugin-merge
GUI-plugin-metriceditor
GUI-plugin-metricident
GUI-plugin-scaling
GUI-plugin-scorepconfig
GUI-plugin-sourcecodeviewer
GUI-plugin-statistics
GUI-plugin-sunburst
GUI-plugin-systemboxplot
GUI-plugin-systemtopology
GUI-plugin-tau2cube
GUI-plugin-treeitemmarker
) do (
echo "Build %%f"
cd  %%f
qmake || goto :error
mingw32-make clean  || goto :error
mingw32-make  || goto :error

cd %PWD%
echo "Copy %%f..."
copy %%f\release\*.exe %TARGET%\bin
copy %%f\release\*.dll %TARGET%\bin
copy %%f\release\*.a   %TARGET%\lib
)

echo "Copy system libraries..."
copy %MINGW%\bin\libgcc_s_*.dll %TARGET%\bin || goto :error
copy %MINGW%\bin\libstdc*-6.dll %TARGET%\bin || goto :error
copy %MINGW%\bin\libwinpthread*.dll %TARGET%\bin || goto :error
echo "Copy Qt libraries..."
echo "Qt located  : %QTDIR%"
copy %QTDIR%\bin\Qt5Core.dll %TARGET%\bin || goto :error
copy %QTDIR%\bin\Qt5Concurrent.dll %TARGET%\bin || goto :error
copy %QTDIR%\bin\Qt5Gui.dll %TARGET%\bin || goto :error
copy %QTDIR%\bin\Qt5Network.dll %TARGET%\bin || goto :error
copy %QTDIR%\bin\Qt5PrintSupport.dll %TARGET%\bin || goto :error
copy %QTDIR%\bin\Qt5Help.dll %TARGET%\bin || goto :error
copy %QTDIR%\bin\Qt5Web*.dll %TARGET%\bin || goto :error
copy %QTDIR%\bin\Qt5Widgets.dll %TARGET%\bin || goto :error

echo "Create directories for plugins..."
mkdir %TARGET%\bin\platforms
mkdir %TARGET%\bin\bearer
mkdir %TARGET%\bin\styles
mkdir %TARGET%\bin\imageformats

echo "Copy Qt platforms..."

copy %QTDIR%\plugins\platforms\qwindows.dll %TARGET%\bin\platforms || goto :error
copy %QTDIR%\plugins\bearer\qgenericbearer.dll %TARGET%\bin\bearer || goto :error
copy %QTDIR%\plugins\styles\qwindowsvistastyle.dll %TARGET%\bin\styles || goto :error
copy %QTDIR%\plugins\imageformats\qgif.dll %TARGET%\bin\imageformats || goto :error
copy %QTDIR%\plugins\imageformats\qicns.dll %TARGET%\bin\imageformats || goto :error
copy %QTDIR%\plugins\imageformats\qico.dll %TARGET%\bin\imageformats || goto :error
copy %QTDIR%\plugins\imageformats\qjpeg.dll %TARGET%\bin\imageformats || goto :error
copy %QTDIR%\plugins\imageformats\qsvg.dll %TARGET%\bin\imageformats || goto :error
copy %QTDIR%\plugins\imageformats\qtga.dll %TARGET%\bin\imageformats || goto :error
copy %QTDIR%\plugins\imageformats\qtiff.dll %TARGET%\bin\imageformats || goto :error
copy %QTDIR%\plugins\imageformats\qwbmp.dll %TARGET%\bin\imageformats || goto :error
copy %QTDIR%\plugins\imageformats\qwebp.dll %TARGET%\bin\imageformats || goto :error


echo "Copy GUI header files..."
copy %srcdir%\src\GUI-qt\display\*.h  %TARGET%\include\cubegui\. || goto :error
copy %srcdir%\vendor\windows\include\*.h  %TARGET%\include\cubegui\. || goto :error
copy %srcdir%\src\GUI-qt\display\plugins\*.h  %TARGET%\include\cubegui\. || goto :error

echo "Copy examples files..."
copy %srcdir%\examples\GUI\trace.cubex  %TARGET%\share\doc\cubegui\examples\. || goto :error




@echo Copy Cube documentation..."
copy  %srcdir%\doc\*.pdf %TARGET%\share\doc\cubegui || goto :error
echo "Copy html docu"
copy %srcdir%\doc\*.tar.gz . || goto :error
tar xzf guide-html.tar.gz || goto :error
echo "Copy unpacked User Guide"
ls -la
xcopy /hievry guide\html\* %TARGET%\share\doc\cubegui\guide\html || goto :error
tar xzf plugins-guide-html.tar.gz || goto :error
echo "Copy unpacked Plugin User Guide"
ls -la
xcopy /hievry plugins-guide\html\* %TARGET%\share\doc\cubegui\plugins-guide\html || goto :error


@echo "Copy Cube images..."
copy  %srcdir%\share\icons\* %TARGET%\share\icons\. || goto :error
@echo "Copy Cube license..."
copy  %srcdir%\COPYING %TARGET%\cubelicense.txt || goto :error

copy  %srcdir%\vendor\windows\cubeinstaller.nsi %TARGET%\.. || goto :error


echo "NOW COMPILE NSIS script..."


:; exit 0
exit /b 0

:error
if errorlevel 1 (
   echo "Failure during copy : %errorlevel%"
   exit /b %errorlevel%
)
